<template>
    <div class="app-container" id="assetAttributeManagement">
        <el-form
            :model="queryParams"
            ref="queryForm"
            size="small"
            :inline="true"
            v-show="showSearch"
            label-width="100px"
        >
            <el-form-item label="资产类型名称" prop="propName">
                <el-input
                    v-model="queryParams.propName"
                    placeholder="请输入资产类型名称"
                    clearable
                    maxlength="50"
                    style="width: 240px"
                    @keyup.enter.native="handleQuery"
                />
            </el-form-item>

            <el-form-item>
                <el-button
                    type="primary"
                    icon="el-icon-search"
                    size="mini"
                    @click="handleQuery"
                    >搜索</el-button
                >
                <el-button
                    icon="el-icon-refresh"
                    size="mini"
                    @click="resetQuery"
                    >重置</el-button
                >
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                    type="primary"
                    plain
                    icon="el-icon-plus"
                    size="mini"
                    @click="handleAdd"
                    >新增</el-button
                >
            </el-col>
            <el-col :span="1.5">
                <el-button
                    type="warning"
                    plain
                    icon="el-icon-download"
                    size="mini"
                    @click="handleExport"
                    >导出</el-button
                >
            </el-col>
            <!-- <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-refresh"
          size="mini"
          @click="handleRefreshCache"
        >刷新缓存</el-button>
      </el-col> -->
            <right-toolbar
                :showSearch.sync="showSearch"
                @queryTable="getList"
            ></right-toolbar>
        </el-row>

        <el-table
            v-loading="loading"
            :data="propInfoList"
            border
            @selection-change="handleSelectionChange"
        >
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column
                align="center"
                label="序号"
                type="index"
                :index="
                    indexContinuation(queryParams.pageNum, queryParams.pageSize)
                "
            />
            <el-table-column
                label="资产类型名称"
                align="center"
                prop="propName"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="所属上级"
                align="center"
                prop="deptName"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="资产编码"
                align="center"
                prop="code"
                :show-overflow-tooltip="true"
            />

            <el-table-column
                label="状态"
                align="center"
                prop="status"
                width="140"
            >
                <template slot-scope="scope">
                    <el-switch
                        active-value="0"
                        inactive-value="1"
                        @change="changeStatus(scope.row)"
                        v-model="scope.row.status"
                    ></el-switch>
                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" width="140">
                <template slot-scope="scope">
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-edit"
                        @click="handleUpdate(scope.row)"
                        >编辑</el-button
                    >
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-delete"
                        @click="handleDelete(scope.row)"
                        >删除</el-button
                    >
                </template>
            </el-table-column>
        </el-table>

        <!-- 添加或修改参数配置对话框 -->
        <el-dialog
            :title="title"
            :visible.sync="open"
            width="600px"
            append-to-body
            :close-on-click-modal="false"
        >
            <el-form
                ref="form"
                :model="form"
                :rules="rules"
                label-width="120px"
            >
                <el-form-item label="资产类型名称" prop="propName">
                    <el-input
                        v-model="form.propName"
                        placeholder="请输入资产类型名称"
                        maxlength="60"
                    />
                </el-form-item>
                <el-form-item label="所属上级" prop="deptId">
                    <treeselect
                        v-model="form.deptId"
                        :options="deptOptions"
                        noChildrenText="没有数据了"
                        noOptionsText="没有数据"
                        noResultsText="没有搜索结果"
                        placeholder="请选择所属上级"
                        @select="select"
                    />
                </el-form-item>
                <el-form-item label="资产编码" prop="code">
                    <el-input
                        v-model="form.code"
                        placeholder="请输入资产编码"
                        maxlength="60"
                    />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listType,
    getType,
    delType,
    addType,
    updateType,
    refreshCache,
} from '@/api/system/dict/type'
import {
    addPropInfo,
    delPropInfo,
    propInfoList,
    updatePropInfo,
} from '@/api/base/base'
import { deptTreeSelect } from '@/api/system/user'
import Treeselect from '@riophae/vue-treeselect'
import '@riophae/vue-treeselect/dist/vue-treeselect.css'

export default {
    name: 'AssetAttributeManagement',
    dicts: ['sys_normal_disable'],
    components: { Treeselect },
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 字典表格数据
            propInfoList: [],
            deptOptions: [],
            // 弹出层标题
            title: '',
            // 是否显示弹出层
            open: false,
            // 日期范围
            dateRange: [],
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                propName: undefined,
                dictType: undefined,
                status: undefined,
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                propName: [
                    {
                        required: true,
                        message: '资产类型名称不能为空',
                        trigger: 'blur',
                    },
                ],
                deptId: [
                    {
                        required: true,
                        message: '所属上级不能为空',
                        trigger: 'blur',
                    },
                ],
                code: [
                    {
                        required: true,
                        message: '资产类型编码不能为空',
                        trigger: 'blur',
                    },
                ],
            },
        }
    },
    created() {
        this.getList()
        this.getDeptTree()
    },
    methods: {
        /** 查询部门下拉树结构 */
        getDeptTree() {
            deptTreeSelect().then((response) => {
                this.deptOptions = response.data
            })
        },
        //更新状态
        changeStatus(row) {
            let param = {
                propId: row.propId,
                status: row.status,
            }
            updatePropInfo(param).then((response) => {
                this.getList()
            })
        },
        /** 查询列表 */
        getList() {
            this.loading = true
            propInfoList(this.queryParams).then((response) => {
                this.propInfoList = response.rows
                this.total = response.total
                this.loading = false
            })
        },
        // 取消按钮
        cancel() {
            this.open = false
            this.reset()
        },
        // 表单重置
        reset() {
            this.form = {}
            this.resetForm('form')
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1
            this.getList()
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.dateRange = []
            this.resetForm('queryForm')
            this.handleQuery()
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset()
            this.open = true
            this.title = '新建'
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map((item) => item.propId)
            this.single = selection.length != 1
            this.multiple = !selection.length
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset()
            propInfoList({ propId: row.propId }).then((response) => {
                this.form = response.rows[0]
            })
            // let formData = row
            // this.form = formData;
            this.open = true
            this.title = '编辑'
        },
        /** 提交按钮 */
        submitForm: function () {
            this.$refs['form'].validate((valid) => {
                if (valid) {
                    if (this.form.propId != undefined) {
                        updatePropInfo(this.form).then((response) => {
                            this.$modal.msgSuccess('修改成功')
                            this.open = false
                            this.getList()
                        })
                    } else {
                        console.log(this.form)
                        addPropInfo(this.form).then((response) => {
                            this.$modal.msgSuccess('新增成功')
                            this.open = false
                            this.getList()
                        })
                    }
                }
            })
        },
        /** 删除按钮操作 */
        handleDelete(row) {
            const propIds = row.propId || this.ids
            this.$modal
                .confirm('是否确认删除该数据项？')
                .then(function () {
                    return delPropInfo(propIds)
                })
                .then(() => {
                    this.getList()
                    this.$modal.msgSuccess('删除成功')
                })
                .catch(() => {})
        },
        /** 导出按钮操作 */
        handleExport() {
            this.download(
                'material/base/maPropInfo/export',
                {
                    ...this.queryParams,
                    dataCondition: this.ids,
                },
                `资产属性_${new Date().getTime()}.xlsx`,
            )
        },
        /** 刷新缓存按钮操作 */
        handleRefreshCache() {
            refreshCache().then(() => {
                this.$modal.msgSuccess('刷新成功')
                this.$store.dispatch('dict/cleanDict')
            })
        },
    },
}
</script>
